#!/usr/bin/env python

import sys

from PyQt6.QtCore import pyqtProperty, pyqtSignal, QCoreApplication, QObject, QUrl
from PyQt6.QtQml import (qmlRegisterType, QQmlComponent, QQmlEngine)


QML = b'''
import QtQuick 2.0
import Test 1.0

Item {

    Creator {
        id: creator
    }

    Consumer {
        id: consumer
        simple: creator.simple
    }
}
'''

class Simple(QObject):
    def __init__(self, parent=None):
        super().__init__(parent)

class Creator(QObject):
    def __init__(self, parent=None):
        super().__init__(parent)
        self._simple = Simple()

    simpleChanged = pyqtSignal()
    @pyqtProperty(Simple, notify=simpleChanged)
    def simple(self):
        return self._simple


class Consumer(QObject):
    def __init__(self, parent=None):
        super().__init__(parent)

    simpleChanged = pyqtSignal()
    @pyqtProperty(Simple, notify=simpleChanged)
    def simple(self):
        return self._simple

    @simple.setter
    def simple(self, simple):
        self._simple = simple


app = QCoreApplication(sys.argv)

qmlRegisterType(Simple, 'Test', 1, 0)
qmlRegisterType(Creator, 'Test', 1, 0)
qmlRegisterType(Consumer, 'Test', 1, 0)

engine = QQmlEngine()

component = QQmlComponent(engine)
component.setData(QML, QUrl())

c = component.create()

if c is None:
    for e in component.errors():
        print("Error:", e.toString());
